@@ -9,11 +9,11 @@ Mojolicious::Plugin::WWWSession - Use WWWW::Session with Mojolicious
 
 =head1 VERSION
 
-Version 0.02
+Version 0.03
 
 =cut
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 
 =head1 SYNOPSIS
@@ -22,6 +22,12 @@ This module allows you to overwrite the standard Mojolicious session with a WWW:
 
 Example :
 
+=head2 Storage backends
+
+You can use one or more of the fallowing backends : 
+
+=head3 File storage
+
 In you apllication module add the fallowing lines 
 
     use Mojolicious::Plugin::WWWSession;
@@ -36,6 +42,68 @@ In you apllication module add the fallowing lines
         ...
     }
 
+See WWW::Session::Storage::File for more details
+
+=head3 Database storage
+
+In you apllication module add the fallowing lines 
+
+    use Mojolicious::Plugin::WWWSession;
+
+    sub startup {
+    
+        ...
+    
+        #Overwrite session
+        $self->plugin( WWWSession => { storage => [ MySQL => { 
+                                                            dbh => $dbh,
+                                                            table => 'sessions',
+                                                            fields => {
+                                                                    sid => 'session_id',
+                                                                    expires => 'expires',
+                                                                    data => 'data'
+                                                            }
+                                                    ] 
+                                      } );
+
+        ...
+    }
+
+The "fields" hasref contains the mapping of session internal data to the column names from MySQL. 
+The keys are the session fields ("sid","expires" and "data") and must all be present. 
+
+The MySQL types of the columns should be :
+
+=over 4
+
+=item * sid => varchar(32)
+
+=item * expires => DATETIME or TIMESTAMP
+
+=item * data => text
+
+=back
+
+See WWW::Session::Storage::MySQL for more details
+
+=head3 Memcached storage
+
+In you apllication module add the fallowing lines 
+
+    use Mojolicious::Plugin::WWWSession;
+
+    sub startup {
+    
+        ...
+    
+        #Overwrite session
+        $self->plugin( WWWSession => { storage => ['Memcached' => {servers => ['127.0.0.1:11211']}] } );
+
+        ...
+    }
+
+See WWW::Session::Storage::Memcached for more details
+
 
 =head1 Using the session
 
@@ -86,7 +154,7 @@ Here is an exmple containing the options you can pass to the plugin:
                      filter => [21..99],
                      }
     }
-    
+    1
 See WWW:Session for more details on possible options and on how you can use the session
 
 If you use the "Storable" serialization engine you can store objects in the session. 
